@@ -2,7 +2,7 @@ import os
 import flask
 import sys
 
-def serve_local_model(port = 3005):
+def serve_local_model():
   sys.path.insert(0, os.getcwd())
   # check that files exist
   print('> Loading predictor.py...')
@@ -33,15 +33,15 @@ def serve_local_model(port = 3005):
     data = {"success": False}
     body = flask.request.json
     print('> Request coming in. Body is:')
-    print(flask.jsonify(body))
+    print(body)
     
     try:
-      data = userProvidedPredictor.predict(body)
+      data = loaded_predictor.predict(body)
     except Exception as e:
       data["message"] = "There was an error while running your model: " + str(e)
 
     return flask.jsonify(data)
 
   # start the flask app, allow remote connections
-  print('> Local server is running on port ' + str(port))
-  app.run(host='0.0.0.0', port=port)
\ No newline at end of file
+  print('> Local server is running on port 3009')
+  app.run(host='0.0.0.0', port=3009)
\ No newline at end of file
