@@ -3,6 +3,8 @@ import os
 from easysettings import EasySettings
 from pathlib import Path
 import requests
+import glob
+import fnmatch
 
 try:
     from importlib import metadata
@@ -28,6 +30,32 @@ def zipdir(path, ziph):
             # remove base folder
             ziph.write(filePath, inZipPath.replace(path.split('/')[-1] + '/', ''))
 
+def add_files_to_zip(ziph, **kwargs):
+  filePaths = []
+
+  if 'include' in kwargs:
+    # include all files
+    for includePath in kwargs['include']:
+      for name in glob.glob(includePath, recursive=True):
+        isExcluded = False
+
+        if 'exclude' in kwargs:
+          for excluded in kwargs['exclude']:
+            if fnmatch.fnmatch(name, excluded):
+              isExcluded = True
+
+        if not isExcluded:
+          filePaths.append(name)
+
+  for filePath in filePaths:
+    print('> Zipping {0}'.format(filePath))
+    isDir = os.path.isdir(filePath)
+
+    if isDir:
+      zipdir(filePath, ziph)
+    else:
+      ziph.write(filePath, filePath)
+
 def set_api_host(host):
   api_host = host
 
